cache_manager_plus library

Classes

CacheItem
CacheManager
CacheManager for orchestrating access to CacheStore/(s), call init to initialise the manager with one or multiple CacheStore
CacheStore
contract defining the shape of a CacheStore used to create custom stores that are passed to the CacheManager to orchestrate communication with
InMemoryCacheStore